@@ -1,6 +1,6 @@
-var _arity = /*#__PURE__*/require('./internal/_arity');
+var _arity = require('./internal/_arity');
+var _curry2 = require('./internal/_curry2');
 
-var _curry2 = /*#__PURE__*/require('./internal/_curry2');
 
 /**
  * Creates a function that is bound to a context.
@@ -19,16 +19,13 @@ var _curry2 = /*#__PURE__*/require('./internal/_curry2');
  * @see R.partial
  * @example
  *
- *      const log = R.bind(console.log, console);
+ *      var log = R.bind(console.log, console);
  *      R.pipe(R.assoc('a', 2), R.tap(log), R.assoc('a', 3))({a: 1}); //=> {a: 3}
  *      // logs {a: 2}
  * @symb R.bind(f, o)(a, b) = f.call(o, a, b)
  */
-
-
-var bind = /*#__PURE__*/_curry2(function bind(fn, thisObj) {
-  return _arity(fn.length, function () {
+module.exports = _curry2(function bind(fn, thisObj) {
+  return _arity(fn.length, function() {
     return fn.apply(thisObj, arguments);
   });
 });
-module.exports = bind;
\ No newline at end of file
